# vecops

This is a simple library for basic operations in vector spaces.

Usage:
    `from vecops import addition`
Calling method:
    `Addition.someMethod()`

Classes:
    `Addition`
    `Inverse`
    `Multiplication`
    `Rotation`
    `Scale`
    `Translation`
    `Reflection`
    `Length`
    `Distance`
   
Installation:
    `pip install vecops`
